@@ -17,11 +17,11 @@ from lumopypackage import userPath
 
 
 def downloadBingImg(select=False):
-    '''
+    """
     该函数会爬取Bing的图片设置成壁纸。
     目前只能用在windows品台下。
     select默认为False的时候不会保存图片，select为True时图片会保存在当前登录用户目录下的\图片\Bing目录。
-    '''
+    """
 
     headers = {
         'User-Agent': userAgent()
@@ -39,7 +39,7 @@ def downloadBingImg(select=False):
     startdate = content['startdate']
 
     # 拼接图片名字
-    imgName = startdate + title + '.jpg'
+    imgName = startdate + '-' + title + '.jpg'
 
     # 判断存图片的路径
     if select:
